@@ -199,8 +199,12 @@ sub _init {
                              'pass',
                              [qw(pass dump void)]
                        );
-    $self->{'show_dualvar'} = Data::Printer::Common::_fetch_scalar_or_default($props, 'show_dualvar', 1);
-
+    $self->{'show_dualvar'} = Data::Printer::Common::_fetch_anyof(
+        $props,
+        'show_dualvar',
+        'lax',
+        [qw(lax strict off)]
+    );
 
     if (exists $props->{as}) {
         my $msg = Data::Printer::Common::_fetch_scalar_or_default($props, 'as', '');
@@ -287,12 +291,16 @@ sub multiline {
             $self->{_current_indent} = $self->{indent};
             $self->index( $self->{_original_index} )
                 if exists $self->{_original_index};
+            $self->hash_separator( $self->{_original_separator} )
+                if exists $self->{_original_separator};
         }
         else {
             $self->{_original_index} = $self->index;
+            $self->index(0);
+            $self->{_original_separator} = $self->hash_separator;
+            $self->hash_separator(':');
             $self->{_linebreak} = ' ';
             $self->{_current_indent} = 0;
-            $self->index(0);
         }
     }
     return $self->{multiline};
